@@ -25,6 +25,15 @@
 
 #include <glib.h>
 
+#ifndef VTE_COMPILATION
+#define _vte_debug_flags _vte_external_debug_flags
+#define _vte_debug_init  _vte_external_debug_init
+#define _vte_debug_on    _vte_external_debug_on
+#if !defined(__GNUC__) || !G_HAVE_GNUC_VARARGS
+#define _vte_debug_print _vte_external_debug_print
+#endif
+#endif
+
 G_BEGIN_DECLS
 
 typedef enum {
@@ -50,7 +59,7 @@ typedef enum {
 	VTE_DEBUG_ADJ		= 1 << 19,
 	VTE_DEBUG_PANGOCAIRO    = 1 << 20,
 	VTE_DEBUG_WIDGET_SIZE   = 1 << 21,
-	VTE_DEBUG_BG            = 1 << 22,
+        VTE_DEBUG_STYLE         = 1 << 22,
 	VTE_DEBUG_RESIZE        = 1 << 23
 } VteDebugFlags;
 
