@@ -33,6 +33,8 @@
 #include "vtepty.h"
 #include "vtepty-private.h"
 #include "vte.h"
+#include "vteenums.h"
+#include "vtetypebuiltins.h"
 #include "vteversion.h"
 
 #include <sys/types.h>
@@ -64,7 +66,6 @@
 #include <glib.h>
 #include <gio/gio.h>
 #include "debug.h"
-#include "pty.h"
 
 #ifdef MSG_NOSIGNAL
 #define PTY_RECVMSG_FLAGS MSG_NOSIGNAL
@@ -370,45 +371,6 @@ vte_pty_child_setup (VtePty *pty)
  * - replace current env rather than adding!
  */
 
-/*
- * __vte_pty_get_argv:
- * @command: the command to run
- * @argv: the argument vector
- * @flags: (inout) flags from #GSpawnFlags
- *
- * Creates an argument vector to pass to g_spawn_async() from @command and
- * @argv, modifying *@flags if necessary.
- *
- * Returns: a newly allocated array of strings. Free with g_strfreev()
- */
-char **
-__vte_pty_get_argv (const char *command,
-                    char **argv,
-                    GSpawnFlags *flags /* inout */)
-{
-	char **argv2;
-	int i, argc;
-
-        g_return_val_if_fail(command != NULL, NULL);
-
-	/* push the command into argv[0] */
-	argc = argv ? g_strv_length (argv) : 0;
-	argv2 = g_new (char *, argc + 2);
-
-	argv2[0] = g_strdup (command);
-
-	for (i = 0; i < argc; i++) {
-		argv2[i+1] = g_strdup (argv[i]);
-	}
-	argv2[i+1] = NULL;
-
-        if (argv) {
-                *flags |= G_SPAWN_FILE_AND_ARGV_ZERO;
-        }
-
-	return argv2;
-}
-
 /*
  * __vte_pty_merge_environ:
  * @envp: environment vector
@@ -472,34 +434,6 @@ __vte_pty_merge_environ (char **envp,
 	return (gchar **) g_ptr_array_free (array, FALSE);
 }
 
-/*
- * __vte_pty_get_pty_flags:
- * @lastlog: %TRUE if the session should be logged to the lastlog
- * @utmp: %TRUE if the session should be logged to the utmp/utmpx log
- * @wtmp: %TRUE if the session should be logged to the wtmp/wtmpx log
- *
- * Combines the @lastlog, @utmp, @wtmp arguments into the coresponding
- * #VtePtyFlags flags.
- *
- * Returns: flags from #VtePtyFlags
- */
-VtePtyFlags
-__vte_pty_get_pty_flags(gboolean lastlog,
-                        gboolean utmp,
-                        gboolean wtmp)
-{
-        VtePtyFlags flags = VTE_PTY_DEFAULT;
-
-        if (!lastlog)
-                flags |= VTE_PTY_NO_LASTLOG;
-        if (!utmp)
-                flags |= VTE_PTY_NO_UTMP;
-        if (!wtmp)
-                flags |= VTE_PTY_NO_WTMP;
-
-        return flags;
-}
-
 /*
  * __vte_pty_spawn:
  * @pty: a #VtePty
@@ -611,54 +545,12 @@ __vte_pty_spawn (VtePty *pty,
         return FALSE;
 }
 
-/*
- * __vte_pty_fork:
- * @pty: a #VtePty
- * @pid: (out) a location to store a #GPid, or %NULL
- * @error: a location to store a #GError, or %NULL
- *
- * Forks and calls vte_pty_child_setup() in the child.
- *
- * Returns: %TRUE on success, or %FALSE on failure with @error filled in
- */
-gboolean
-__vte_pty_fork(VtePty *pty,
-               GPid *pid,
-               GError **error)
-{
-#ifdef HAVE_FORK
-        gboolean ret = TRUE;
-
-        *pid = fork();
-        switch (*pid) {
-                case -1:
-                        g_set_error(error,
-                                    G_SPAWN_ERROR,
-                                    G_SPAWN_ERROR_FAILED,
-                                    "Unable to fork: %s",
-                                    g_strerror(errno));
-                        ret = FALSE;
-                case 0: /* child */
-                        vte_pty_child_setup(pty);
-                        break;
-                default: /* parent */
-                        break;
-        }
-
-	return ret;
-#else /* !HAVE_FORK */
-        g_set_error_literal(error, G_SPAWN_ERROR, G_SPAWN_ERROR_FAILED,
-                            "No fork implementation");
-        return FALSE;
-#endif /* HAVE_FORK */
-}
-
 /**
  * vte_pty_set_size:
  * @pty: a #VtePty
  * @rows: the desired number of rows
  * @columns: the desired number of columns
- * @error: (allow-none); return location to store a #GError, or %NULL
+ * @error: (allow-none): return location to store a #GError, or %NULL
  *
  * Attempts to resize the pseudo terminal's window size.  If successful, the
  * OS kernel will send #SIGWINCH to the child process group.
@@ -675,15 +567,12 @@ vte_pty_set_size(VtePty *pty,
                  int columns,
                  GError **error)
 {
-        VtePtyPrivate *priv;
 	struct winsize size;
         int master;
 	int ret;
 
         g_return_val_if_fail(VTE_IS_PTY(pty), FALSE);
 
-        priv = pty->priv;
-
         master = vte_pty_get_fd(pty);
 
 	memset(&size, 0, sizeof(size));
@@ -734,15 +623,12 @@ vte_pty_get_size(VtePty *pty,
                  int *columns,
                  GError **error)
 {
-        VtePtyPrivate *priv;
 	struct winsize size;
         int master;
 	int ret;
 
         g_return_val_if_fail(VTE_IS_PTY(pty), FALSE);
 
-        priv = pty->priv;
-
         master = vte_pty_get_fd(pty);
 
 	memset(&size, 0, sizeof(size));
@@ -1644,7 +1530,7 @@ vte_pty_init (VtePty *pty)
         priv->foreign = FALSE;
         priv->using_helper = FALSE;
         priv->helper_tag = NULL;
-        priv->term = vte_terminal_get_default_emulation(NULL /* that's ok, this function is just retarded */); /* already interned */
+        priv->term = vte_get_default_emulation(); /* already interned */
 }
 
 static void
@@ -1810,8 +1696,9 @@ vte_pty_error_quark(void)
 }
 
 /**
- * vte_pty_new:
+ * vte_pty_new_sync: (constructor)
  * @flags: flags from #VtePtyFlags
+ * @cancellable: (allow-none): a #GCancellable, or %NULL
  * @error: (allow-none): return location for a #GError, or %NULL
  *
  * Allocates a new pseudo-terminal.
@@ -1847,19 +1734,21 @@ vte_pty_error_quark(void)
  * Since: 0.26
  */
 VtePty *
-vte_pty_new (VtePtyFlags flags,
-             GError **error)
+vte_pty_new_sync (VtePtyFlags flags,
+                  GCancellable *cancellable,
+                  GError **error)
 {
         return g_initable_new (VTE_TYPE_PTY,
-                               NULL /* cancellable */,
+                               cancellable,
                                error,
                                "flags", flags,
                                NULL);
 }
 
 /**
- * vte_pty_new_foreign:
+ * vte_pty_new_foreign_sync: (constructor)
  * @fd: (transfer full): a file descriptor to the PTY
+ * @cancellable: (allow-none): a #GCancellable, or %NULL
  * @error: (allow-none): return location for a #GError, or %NULL
  *
  * Creates a new #VtePty for the PTY master @fd.
@@ -1874,13 +1763,14 @@ vte_pty_new (VtePtyFlags flags,
  * Since: 0.26
  */
 VtePty *
-vte_pty_new_foreign (int fd,
-                     GError **error)
+vte_pty_new_foreign_sync (int fd,
+                          GCancellable *cancellable,
+                          GError **error)
 {
         g_return_val_if_fail(fd >= 0, NULL);
 
         return g_initable_new (VTE_TYPE_PTY,
-                               NULL /* cancellable */,
+                               cancellable,
                                error,
                                "fd", fd,
                                NULL);
@@ -1932,216 +1822,3 @@ vte_pty_set_term (VtePty *pty,
         priv->term = emulation;
         g_object_notify(G_OBJECT(pty), "term");
 }
-
-/* Reimplementation of the ugly deprecated APIs _vte_pty_*() */
-
-#ifndef VTE_DISABLE_DEPRECATED_SOURCE
-
-static GHashTable *fd_to_pty_hash = NULL;
-
-static VtePty *
-get_vte_pty_for_fd (int fd)
-{
-        VtePty *pty;
-
-        if (fd_to_pty_hash != NULL &&
-            (pty = g_hash_table_lookup(fd_to_pty_hash, &fd)) != NULL)
-                return pty;
-
-        g_warning("No VtePty found for fd %d!\n", fd);
-        return NULL;
-}
-
-/**
- * _vte_pty_open:
- * @child: location to store the new process's ID
- * @env_add: a list of environment variables to add to the child's environment
- * @command: name of the binary to run
- * @argv: arguments to pass to @command
- * @directory: directory to start the new command in, or %NULL
- * @columns: desired window columns
- * @rows: desired window rows
- * @lastlog: %TRUE if the lastlog should be updated
- * @utmp: %TRUE if the utmp or utmpx log should be updated
- * @wtmp: %TRUE if the wtmp or wtmpx log should be updated
- *
- * Starts a new copy of @command running under a psuedo-terminal, optionally in
- * the supplied @directory, with window size set to @rows x @columns
- * and variables in @env_add added to its environment.  If any combination of
- * @lastlog, @utmp, and @wtmp is set, then the session is logged in the
- * corresponding system files.
- *
- * Returns: an open file descriptor for the pty master, -1 on failure
- *
- * Deprecated: 0.26: Use #VtePty together with fork() or the g_spawn_async() family of functions instead
- */
-int
-_vte_pty_open(pid_t *child,
-              char **env_add,
-              const char *command,
-              char **argv,
-              const char *directory,
-              int columns,
-              int rows,
-              gboolean lastlog,
-              gboolean utmp,
-              gboolean wtmp)
-{
-        VtePty *pty;
-        GPid pid;
-        gboolean ret;
-
-        pty = vte_pty_new(__vte_pty_get_pty_flags (lastlog, utmp, wtmp), NULL);
-        if (pty == NULL)
-                return -1;
-
-        if (command != NULL) {
-                char **real_argv;
-                GSpawnFlags spawn_flags;
-
-                spawn_flags = G_SPAWN_CHILD_INHERITS_STDIN |
-                              G_SPAWN_SEARCH_PATH;
-                real_argv = __vte_pty_get_argv(command, argv, &spawn_flags);
-                ret = __vte_pty_spawn(pty,
-                                      directory,
-                                      real_argv,
-                                      env_add,
-                                      spawn_flags,
-                                      NULL, NULL,
-                                      &pid,
-                                      NULL);
-                g_strfreev(real_argv);
-        } else {
-                ret = __vte_pty_fork(pty, &pid, NULL);
-        }
-
-        if (!ret) {
-                g_object_unref(pty);
-                return -1;
-        }
-
-        vte_pty_set_size(pty, rows, columns, NULL);
-
-        /* Stash the pty in the hash so we can later retrieve it by FD */
-        if (fd_to_pty_hash == NULL) {
-                fd_to_pty_hash = g_hash_table_new_full(g_int_hash,
-                                                       g_int_equal,
-                                                       NULL,
-                                                       (GDestroyNotify) g_object_unref);
-        }
-
-        g_hash_table_insert(fd_to_pty_hash, &pty->priv->pty_fd, pty /* adopt refcount */);
-
-        if (child)
-                *child = (pid_t) pid;
-
-        return vte_pty_get_fd(pty);
-}
-
-/**
- * _vte_pty_get_size:
- * @master: the file descriptor of the PTY master
- * @columns: a place to store the number of columns
- * @rows: a place to store the number of rows
- *
- * Attempts to read the pseudo terminal's window size.
- *
- * Returns: 0 on success, -1 on failure.
- *
- * Deprecated: 0.26: Use #VtePty and vte_pty_get_size() instead
- */
-int
-_vte_pty_get_size(int master,
-                  int *columns,
-                  int *rows)
-{
-        VtePty *pty;
-
-        if ((pty = get_vte_pty_for_fd(master)) == NULL)
-                return -1;
-
-        if (vte_pty_get_size(pty, rows, columns, NULL))
-                return 0;
-
-        return -1;
-}
-
-/**
- * _vte_pty_set_size:
- * @master: the file descriptor of the PTY master
- * @columns: the desired number of columns
- * @rows: the desired number of rows
- *
- * Attempts to resize the pseudo terminal's window size.  If successful, the
- * OS kernel will send #SIGWINCH to the child process group.
- *
- * Returns: 0 on success, -1 on failure.
- *
- * Deprecated: 0.26: Use #VtePty and vte_pty_set_size() instead
- */
-int
-_vte_pty_set_size(int master,
-                  int columns,
-                  int rows)
-{
-        VtePty *pty;
-
-        if ((pty = get_vte_pty_for_fd(master)) == NULL)
-                return -1;
-
-        if (vte_pty_set_size(pty, rows, columns, NULL))
-                return 0;
-
-        return -1;
-}
-
-/**
- * _vte_pty_set_utf8:
- * @pty: The pty master descriptor.
- * @utf8: Whether or not the pty is in UTF-8 mode.
- *
- * Tells the kernel whether the terminal is UTF-8 or not, in case it can make
- * use of the info.  Linux 2.6.5 or so defines IUTF8 to make the line
- * discipline do multibyte backspace correctly.
- *
- * Deprecated: 0.26: Use #VtePty and vte_pty_set_utf8() instead
- */
-void _vte_pty_set_utf8(int master,
-                       gboolean utf8)
-{
-        VtePty *pty;
-
-        if ((pty = get_vte_pty_for_fd(master)) == NULL)
-                return;
-
-        vte_pty_set_utf8(pty, utf8, NULL);
-}
-
-/**
- * _vte_pty_close:
- * @pty: the pty master descriptor.
- *
- * Cleans up the PTY associated with the descriptor, specifically any logging
- * performed for the session.  The descriptor itself remains open.
- *
- * Deprecated: 0.26: Use #VtePty and vte_pty_close() instead
- */
-void _vte_pty_close(int master)
-{
-        VtePty *pty;
-
-        if ((pty = get_vte_pty_for_fd(master)) == NULL)
-                return;
-
-        /* Prevent closing the FD */
-        pty->priv->pty_fd = -1;
-
-        g_hash_table_remove(fd_to_pty_hash, &master);
-
-        if (g_hash_table_size(fd_to_pty_hash) == 0) {
-                g_hash_table_destroy(fd_to_pty_hash);
-                fd_to_pty_hash = NULL;
-        }
-}
-
-#endif /* !VTE_DISABLE_DEPRECATED_SOURCE */
