@@ -46,7 +46,6 @@
 #include "debug.h"
 #include "vteconv.h"
 #include "vtedraw.h"
-#include "reaper.h"
 #include "ring.h"
 #include "caps.h"
 
@@ -86,7 +85,6 @@ G_BEGIN_DECLS
 /* More color defines in vterowdata.h */
 
 #define VTE_SCROLLBACK_INIT		512
-#define VTE_SATURATION_MAX		10000
 #define VTE_DEFAULT_CURSOR		GDK_XTERM
 #define VTE_MOUSING_CURSOR		GDK_LEFT_PTR
 #define VTE_TAB_MAX			999
@@ -113,15 +111,11 @@ G_BEGIN_DECLS
 #define VTE_COLOR_SOURCE_ESCAPE 0
 #define VTE_COLOR_SOURCE_API 1
 
+#define VTE_FONT_SCALE_MIN (.25)
+#define VTE_FONT_SCALE_MAX (4.)
+
 #define I_(string) (g_intern_static_string(string))
 
-
-typedef enum {
-        VTE_REGEX_GREGEX,
-        VTE_REGEX_VTE,
-        VTE_REGEX_UNDECIDED
-} VteRegexMode;
-
 typedef enum {
   VTE_REGEX_CURSOR_GDKCURSOR,
   VTE_REGEX_CURSOR_GDKCURSORTYPE,
@@ -141,14 +135,8 @@ typedef enum {
 /* A match regex, with a tag. */
 struct vte_match_regex {
 	gint tag;
-        VteRegexMode mode;
-        union { /* switched on |mode| */
-              struct {
-                    GRegex *regex;
-                    GRegexMatchFlags flags;
-              } gregex;
-              struct _vte_regex *reg;
-        } regex;
+        GRegex *regex;
+        GRegexMatchFlags match_flags;
         VteRegexCursorMode cursor_mode;
         union {
 	       GdkCursor *cursor;
@@ -166,10 +154,6 @@ typedef enum _VteKeymode {
 
 typedef struct _VteScreen VteScreen;
 
-typedef struct _VteWordCharRange {
-	gunichar start, end;
-} VteWordCharRange;
-
 typedef struct _VtePaletteColor {
 	struct {
 		PangoColor color;
@@ -179,6 +163,10 @@ typedef struct _VtePaletteColor {
 
 /* Terminal private data. */
 struct _VteTerminalPrivate {
+        /* Metric and sizing data: dimensions of the window */
+        glong row_count;
+        glong column_count;
+
 	/* Emulation setup data. */
 	struct _vte_termcap *termcap;	/* termcap storage */
 	struct _vte_matcher *matcher;	/* control sequence matcher */
@@ -208,11 +196,11 @@ struct _VteTerminalPrivate {
 	guint pty_output_source;
 	gboolean pty_input_active;
 	GPid pty_pid;			/* pid of child using pty slave */
-	VteReaper *pty_reaper;
-        int child_exit_status;
+	guint child_watch_source;
 
 	/* Input data queues. */
 	const char *encoding;		/* the pty's encoding */
+        int iso2022_utf8_ambiguous_width;
 	struct _vte_iso2022_state *iso2022;
 	struct _vte_incoming_chunk{
 		struct _vte_incoming_chunk *next;
@@ -228,11 +216,11 @@ struct _VteTerminalPrivate {
 	glong max_input_bytes;
 
 	/* Output data queue. */
-	VteBuffer *outgoing;	/* pending input characters */
+	VteByteArray *outgoing;	/* pending input characters */
 	VteConv outgoing_conv;
 
 	/* IConv buffer. */
-	VteBuffer *conv_buffer;
+	VteByteArray *conv_buffer;
 
 	/* Screen data.  We support the normal screen, and an alternate
 	 * screen, which seems to be a DEC-specific feature. */
@@ -248,6 +236,7 @@ struct _VteTerminalPrivate {
 		gboolean sendrecv_mode;	/* sendrecv mode */
 		gboolean insert_mode;	/* insert mode */
 		gboolean linefeed_mode;	/* linefeed mode */
+		gboolean bracketed_paste_mode;
 		struct vte_scrolling_region {
 			int start, end;
 		} scrolling_region;	/* the region we scroll in */
@@ -271,7 +260,6 @@ struct _VteTerminalPrivate {
 	} normal_screen, alternate_screen, *screen;
 
 	/* Selection information. */
-	GArray *word_chars;
 	gboolean has_selection;
 	gboolean selecting;
 	gboolean selecting_after_threshold;
@@ -290,7 +278,7 @@ struct _VteTerminalPrivate {
 	VteVisualPosition selection_start, selection_end;
 
 	/* Miscellaneous options. */
-	VteTerminalEraseBinding backspace_binding, delete_binding;
+	VteEraseBinding backspace_binding, delete_binding;
 	gboolean meta_sends_escape;
 	gboolean audible_bell;
 	gboolean visible_bell;
@@ -304,7 +292,6 @@ struct _VteTerminalPrivate {
 	gboolean text_inserted_flag;
 	gboolean text_deleted_flag;
 	gboolean rewrap_on_resize;
-	gboolean bracketed_paste_mode;
 
 	/* Scrolling options. */
 	gboolean scroll_background;
@@ -314,11 +301,11 @@ struct _VteTerminalPrivate {
 	long scrollback_lines;
 
 	/* Cursor shape */
-	VteTerminalCursorShape cursor_shape;
+	VteCursorShape cursor_shape;
         float cursor_aspect_ratio;
 
 	/* Cursor blinking. */
-        VteTerminalCursorBlinkMode cursor_blink_mode;
+        VteCursorBlinkMode cursor_blink_mode;
 	gboolean cursor_blink_state;
 	guint cursor_blink_tag;           /* cursor blinking timeout ID */
         gint cursor_blink_cycle;          /* gtk-cursor-blink-time / 2 */
@@ -329,6 +316,7 @@ struct _VteTerminalPrivate {
 	gboolean has_focus;               /* is the terminal window focused */
 
 	/* Input device options. */
+        gboolean input_enabled;
 	time_t last_keypress_time;
 
 	int mouse_tracking_mode; /* this is of type MouseTrackingMode,
@@ -344,7 +332,6 @@ struct _VteTerminalPrivate {
 	/* State variables for handling match checks. */
 	char *match_contents;
 	GArray *match_attributes;
-        VteRegexMode match_regex_mode;
 	GArray *match_regexes;
 	char *match;
 	int match_tag;
@@ -353,14 +340,21 @@ struct _VteTerminalPrivate {
 
 	/* Search data. */
 	GRegex *search_regex;
+        GRegexMatchFlags search_match_flags;
 	gboolean search_wrap_around;
 	GArray *search_attrs; /* Cache attrs */
 
 	/* Data used when rendering the text which does not require server
 	 * resources and which can be kept after unrealizing. */
+        PangoFontDescription *unscaled_font_desc;
 	PangoFontDescription *fontdesc;
-	VteTerminalAntiAlias fontantialias;
+        gdouble font_scale;
 	gboolean fontdirty;
+        glong char_ascent;
+        glong char_descent;
+        /* dimensions of character cells */
+        glong char_width;
+        glong char_height;
 
 	/* Data used when rendering the text which reflects server resources
 	 * and data, which should be dropped when unrealizing and (re)created
@@ -392,22 +386,17 @@ struct _VteTerminalPrivate {
 	gboolean contents_changed_pending;
 
 	/* window name changes */
+        gchar *window_title;
 	gchar *window_title_changed;
+        gchar *icon_title;
 	gchar *icon_title_changed;
         gchar *current_directory_uri;
         gchar *current_directory_uri_changed;
         gchar *current_file_uri;
         gchar *current_file_uri_changed;
 
-	/* Background images/"transparency". */
-	guint root_pixmap_changed_tag;
-	gboolean bg_update_pending;
-	gboolean bg_transparent;
-	GdkPixbuf *bg_pixbuf;
-	char *bg_file;
-	PangoColor bg_tint_color;
-	guint16 bg_saturation;	/* out of VTE_SATURATION_MAX */
-	guint16 bg_opacity;
+	/* Background */
+        gdouble background_alpha;
 
 	/* Key modifiers. */
 	GdkModifierType modifiers;
@@ -422,10 +411,11 @@ struct _VteTerminalPrivate {
 	glong strikethrough_position;
 
         /* Style stuff */
-        GtkBorder inner_border;
+        GtkBorder padding;
 
         /* GtkScrollable impl */
         GtkAdjustment *hadjustment; /* unused */
+        GtkAdjustment *vadjustment;
         guint hscroll_policy : 1; /* unused */
 
         guint vscroll_policy : 1;
@@ -467,7 +457,7 @@ PangoColor *_vte_terminal_get_color(const VteTerminal *terminal, int idx);
 void _vte_terminal_set_color_internal(VteTerminal *terminal,
                                       int idx,
                                       int source,
-                                      const GdkColor *color);
+                                      const PangoColor *color);
 
 void _vte_terminal_inline_error_message(VteTerminal *terminal, const char *format, ...) G_GNUC_PRINTF(2,3);
 
@@ -480,6 +470,18 @@ void _vte_terminal_handle_sequence(VteTerminal *terminal,
 				   const char *match_s,
 				   GQuark match,
 				   GValueArray *params);
+gboolean _vte_terminal_xy_to_grid(VteTerminal *terminal,
+                                  long x,
+                                  long y,
+                                  long *col,
+                                  long *row);
+gboolean _vte_terminal_size_to_grid_size(VteTerminal *terminal,
+                                         long w,
+                                         long h,
+                                         long *cols,
+                                         long *rows);
+
+gboolean _vte_is_word_char(gunichar c) G_GNUC_CONST;
 
 G_END_DECLS
 
